==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebTabHeaderConnectionEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTabHeaderConnectionEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabHeaderConnectionEventArgsDescription, _super);
    function WebTabHeaderConnectionEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebTabHeaderConnectionEventArgsDescription.prototype.get_type = function () {
        return "WebTabHeaderConnectionEventArgs";
    };
    Object.defineProperty(WebTabHeaderConnectionEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTabHeaderConnectionEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebTabHeaderConnectionEventArgsDescription.$t = markType(WebTabHeaderConnectionEventArgsDescription, 'WebTabHeaderConnectionEventArgsDescription', Description.$);
    return WebTabHeaderConnectionEventArgsDescription;
}(Description));
export { WebTabHeaderConnectionEventArgsDescription };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebTabHeaderConnectionEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTabHeaderConnectionEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabHeaderConnectionEventArgsDescription, _super);
    function WebTabHeaderConnectionEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.h = null;
        return _this;
    }
    WebTabHeaderConnectionEventArgsDescription.prototype.get_type = function () {
        return "WebTabHeaderConnectionEventArgs";
    };
    Object.defineProperty(WebTabHeaderConnectionEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTabHeaderConnectionEventArgsDescription.prototype, "pane", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Pane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTabHeaderConnectionEventArgsDescription.prototype, "element", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Element");
        },
        enumerable: true,
        configurable: true
    });
    WebTabHeaderConnectionEventArgsDescription.$t = markType(WebTabHeaderConnectionEventArgsDescription, 'WebTabHeaderConnectionEventArgsDescription', Description.$);
    return WebTabHeaderConnectionEventArgsDescription;
}(Description));
export { WebTabHeaderConnectionEventArgsDescription };
